@@ -137,7 +137,7 @@ class MyWhatify:
                 if len(ret_list) > 0:
                     for pred_check in ret_list:
                         if pred_check['ensemble_id'] == ensemble_id and pred_check['datasource_name'] == data_name:
-                            return int(ret_list[0]['id']), True, None
+                            return int(pred_check['id']), True, None
             try:
                 if not (file_path or data_id):
                     data_id = my_toolkit.Datasource.create_from_dataframe(df=data_file, data_source_name=data_name,
